%---------------------------------------------------------------------------
%                    LICENSE NOTICE
%
% Copyright 2023, Bruno Gil, Meysam Keshavarz, Dominic Wales, Ara Darzi, Eric Yeatman
%
% The program is distributed under the terms of the GNU General Public License, version 3 (GPL-3.0)  
%
%
% This program is free software: you can redistribute it and/or modify it under 
% the terms of the GNU General Public License as published by the Free Software Foundation,
% either version 3 of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
% without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
% See the GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License along with this program. 
% If not, see <https://www.gnu.org/licenses/>
%
%---------------------------------------------------------------------------------
%% SECTION 1) Creation of the vector of features for the PBS data (control). Please see Supplementary Information for more details about algorithm's theory

clear all
close all
clc

CNP_voltage_mean = 0.595;
CNP_resistance_mean = 3350;
CNP_FWHM_mean = 0.175;
CNP_slope_mean = 67;
CNP_inter_mean = 1400;

Raman_ratio_DG_band_mean = 15.87/65.78;
Raman_ratio_G2D_band_mean = 65.78/83.71;
Raman_shift_D_band_mean = 1508;
Raman_shift_G_band_mean = 1607;
Raman_shift_2D_band_mean = 2702;
Raman_FWHM_first_peak_mean = 57.3;
Raman_FWHM_second_peak_mean = 51;
Raman_FWHM_third_peak_mean = 14;
Raman_FWHM_fourth_peak_mean = 27;
Raman_FWHM_fifth_peak_mean = 9;

mean_vector_PBS = [CNP_voltage_mean CNP_resistance_mean CNP_FWHM_mean CNP_slope_mean CNP_inter_mean ...
                   0.4*Raman_ratio_DG_band_mean Raman_ratio_G2D_band_mean Raman_shift_D_band_mean ...
                   Raman_shift_G_band_mean Raman_shift_2D_band_mean Raman_FWHM_first_peak_mean ...
                   Raman_FWHM_second_peak_mean Raman_FWHM_third_peak_mean Raman_FWHM_fourth_peak_mean ...
                   Raman_FWHM_fifth_peak_mean];
               

%% SECTION 2) Creation of the weights for the classification matrix (training subset) based on the vector of features for the 3 exosomes types (TNBC, CRC, FB)

% ---- TNBC ------

TNBC_CNP_voltage_mean = [0.57 0.53 0.52 0.55 0.54 0.535 0.555 0.532 0.561 0.545 0.56 0.57 0.53 0.52 0.52];
TNBC_CNP_voltage_var = [];
for i=1:length(TNBC_CNP_voltage_mean)
    TNBC_CNP_voltage_var = [TNBC_CNP_voltage_var; abs(TNBC_CNP_voltage_mean(i) - 0.56)];
end
TNBC_CNP_voltage_var = mean(TNBC_CNP_voltage_var)/CNP_voltage_mean*100;

TNBC_CNP_resistance_mean = [2700 2680 2660 2710 2730 2690 2640 2650 2705 2673 2641 2729 2722 2681 2630];
TNBC_CNP_resistance_var = [];
for i=1:length(TNBC_CNP_resistance_mean)
    TNBC_CNP_resistance_var = [TNBC_CNP_resistance_var; abs(TNBC_CNP_resistance_mean(i) - 2670)];
end
TNBC_CNP_resistance_var = mean(TNBC_CNP_resistance_var)/CNP_resistance_mean*100;

TNBC_CNP_FWHM_mean = [0.215 0.22 0.21 0.204 0.215 0.218 0.223 0.221 0.203 0.207 0.204 0.21 0.225 0.224 0.217];
TNBC_CNP_FWHM_var = [];
for i=1:length(TNBC_CNP_FWHM_mean)
    TNBC_CNP_FWHM_var = [TNBC_CNP_FWHM_var; abs(TNBC_CNP_FWHM_mean(i) - 0.2)];
end
TNBC_CNP_FWHM_var = mean(TNBC_CNP_FWHM_var)/CNP_FWHM_mean*100;

TNBC_CNP_slope_mean = [38 49 43 39 40 41 40 37 38 39.5];
TNBC_CNP_slope_var = [];
for i=1:length(TNBC_CNP_slope_mean)
    TNBC_CNP_slope_var = [TNBC_CNP_slope_var; abs(TNBC_CNP_slope_mean(i) - 44)];
end
TNBC_CNP_slope_var = mean(TNBC_CNP_slope_var)/CNP_slope_mean*100;

TNBC_CNP_inter_mean = [1500 1530 1505 1490 1503 1510 1520 1535 1520 1480];
TNBC_CNP_inter_var = [];
for i=1:length(TNBC_CNP_inter_mean)
    TNBC_CNP_inter_var = [TNBC_CNP_inter_var; abs(TNBC_CNP_inter_mean(i) - 1515)];
end
TNBC_CNP_inter_var = mean(TNBC_CNP_inter_var)/CNP_inter_mean*100;

TNBC_Raman_ratio_DG_band_mean = [0.66 0.64 0.53 0.57 0.63 0.66 0.65 0.59 0.57 0.61 0.58 0.65 0.54 0.63 0.61];
TNBC_Raman_ratio_DG_band_var = [];
for i=1:length(TNBC_Raman_ratio_DG_band_mean)
    TNBC_Raman_ratio_DG_band_var = [TNBC_Raman_ratio_DG_band_var; abs(TNBC_Raman_ratio_DG_band_mean(i) - 0.65)];
end
TNBC_Raman_ratio_DG_band_var = mean(TNBC_Raman_ratio_DG_band_var)/Raman_ratio_DG_band_mean*100;

TNBC_Raman_ratio_G2D_band_mean = [0.99 1 0.93 0.94 0.98 0.975 0.987 0.945 0.992 0.994 0.97 1 0.98 0.94 0.93];
TNBC_Raman_ratio_G2D_band_var = [];
for i=1:length(TNBC_Raman_ratio_G2D_band_mean)
    TNBC_Raman_ratio_G2D_band_var = [TNBC_Raman_ratio_G2D_band_var; abs(TNBC_Raman_ratio_G2D_band_mean(i) - 0.98)];
end
TNBC_Raman_ratio_G2D_band_var = mean(TNBC_Raman_ratio_G2D_band_var)/Raman_ratio_G2D_band_mean*100;

TNBC_Raman_shift_D_band_mean = [1495 1494 1498 1500 1493 1490 1497 1501 1502 1496 1495 1493 1499 1497 1494];
TNBC_Raman_shift_D_band_var = [];
for i=1:length(TNBC_Raman_shift_D_band_mean)
    TNBC_Raman_shift_D_band_var = [TNBC_Raman_shift_D_band_var; abs(TNBC_Raman_shift_D_band_mean(i) - 1490)];
end
TNBC_Raman_shift_D_band_var = mean(TNBC_Raman_shift_D_band_var)/Raman_shift_D_band_mean*100;

TNBC_Raman_shift_G_band_mean = [1605 1609 1620 1615 1614 1618 1622 1608 1610 1617 1606 1619 1621 1609 1606];
TNBC_Raman_shift_G_band_var = [];
for i=1:length(TNBC_Raman_shift_G_band_mean)
    TNBC_Raman_shift_G_band_var = [TNBC_Raman_shift_G_band_var; abs(TNBC_Raman_shift_G_band_mean(i) - 1600)];
end
TNBC_Raman_shift_G_band_var = mean(TNBC_Raman_shift_G_band_var)/Raman_shift_G_band_mean*100;

TNBC_Raman_shift_2D_band_mean = [2705 2710 2720 2690 2695 2702 2706 2708 2699 2701 2706 2691 2696 2707 2692];
TNBC_Raman_shift_2D_band_var = [];
for i=1:length(TNBC_Raman_shift_2D_band_mean)
    TNBC_Raman_shift_2D_band_var = [TNBC_Raman_shift_2D_band_var; abs(TNBC_Raman_shift_2D_band_mean(i) - 2700)];
end
TNBC_Raman_shift_2D_band_var = mean(TNBC_Raman_shift_2D_band_var)/Raman_shift_2D_band_mean*100;

TNBC_Raman_FWHM_first_peak_mean = [34 33 32 31 35 30 36 31 32.5 33.5 32 33 34.5 31 35];
TNBC_Raman_FWHM_first_peak_var = [];
for i=1:length(TNBC_Raman_FWHM_first_peak_mean)
    TNBC_Raman_FWHM_first_peak_var = [TNBC_Raman_FWHM_first_peak_var; abs(TNBC_Raman_FWHM_first_peak_mean(i) - 30)];
end
TNBC_Raman_FWHM_first_peak_var = mean(TNBC_Raman_FWHM_first_peak_var)/Raman_FWHM_first_peak_mean*100;

TNBC_Raman_FWHM_second_peak_mean = [28.2 27 27.5 26 28 28.3 29 26.9 27.3 27.8];
TNBC_Raman_FWHM_second_peak_var = [];
for i=1:length(TNBC_Raman_FWHM_second_peak_mean)
    TNBC_Raman_FWHM_second_peak_var = [TNBC_Raman_FWHM_second_peak_var; abs(TNBC_Raman_FWHM_second_peak_mean(i) - 28)];
end
TNBC_Raman_FWHM_second_peak_var = mean(TNBC_Raman_FWHM_second_peak_var)/Raman_FWHM_second_peak_mean*100;

TNBC_Raman_FWHM_third_peak_mean = [23 22.5 23.4 24.1 25 24.3 23.8 23.1 25 22.7 23.2 23.5 24.2 25.1 23];
TNBC_Raman_FWHM_third_peak_var = [];
for i=1:length(TNBC_Raman_FWHM_third_peak_mean)
    TNBC_Raman_FWHM_third_peak_var = [TNBC_Raman_FWHM_third_peak_var; abs(TNBC_Raman_FWHM_third_peak_mean(i) - 24)];
end
TNBC_Raman_FWHM_third_peak_var = mean(TNBC_Raman_FWHM_third_peak_var)/Raman_FWHM_third_peak_mean*100;

TNBC_Raman_FWHM_fourth_peak_mean = [27 27.3 26.8 26.9 27.2 28.1 27.6 26.4 26.2 27.05 27.2 26.8 27.3 26.4 28.2];
TNBC_Raman_FWHM_fourth_peak_var = [];
for i=1:length(TNBC_Raman_FWHM_fourth_peak_mean)
    TNBC_Raman_FWHM_fourth_peak_var = [TNBC_Raman_FWHM_fourth_peak_var; abs(TNBC_Raman_FWHM_fourth_peak_mean(i) - 28)];
end
TNBC_Raman_FWHM_fourth_peak_var = mean(TNBC_Raman_FWHM_fourth_peak_var)/Raman_FWHM_fourth_peak_mean*100;

TNBC_Raman_FWHM_fifth_peak_mean = [23.5 24 24.7 22 24.3 23.8 23.4 25 24.1 23.3 22.5 25.2 24.3 24.7 23.9];
TNBC_Raman_FWHM_fifth_peak_var = [];
for i=1:length(TNBC_Raman_FWHM_fifth_peak_mean)
    TNBC_Raman_FWHM_fifth_peak_var = [TNBC_Raman_FWHM_fifth_peak_var; abs(TNBC_Raman_FWHM_fifth_peak_mean(i) - 23)];
end
TNBC_Raman_FWHM_fifth_peak_var = mean(TNBC_Raman_FWHM_fifth_peak_var)/Raman_FWHM_fifth_peak_mean*100;

TNBC_CNP_voltage_weight = 10*TNBC_CNP_voltage_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);
                                                    
TNBC_CNP_resistance_weight = 10*TNBC_CNP_resistance_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);
                                                    
TNBC_CNP_FWHM_weight = TNBC_CNP_FWHM_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);

TNBC_CNP_slope_weight = TNBC_CNP_slope_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);

TNBC_CNP_inter_weight = TNBC_CNP_inter_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
TNBC_Raman_ratio_DG_band_weight = 0.5*TNBC_Raman_ratio_DG_band_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
TNBC_Raman_ratio_G2D_band_weight = TNBC_Raman_ratio_G2D_band_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
TNBC_Raman_shift_D_band_weight = TNBC_Raman_shift_D_band_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);                                                     
                                                                           
TNBC_Raman_shift_G_band_weight = TNBC_Raman_shift_G_band_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);  
                                                    
TNBC_Raman_shift_2D_band_weight = TNBC_Raman_shift_2D_band_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);                                                     
                                                    
TNBC_Raman_FWHM_first_peak_weight = TNBC_Raman_FWHM_first_peak_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);          
                                                                                                        
TNBC_Raman_FWHM_second_peak_weight = TNBC_Raman_FWHM_second_peak_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);
                                                                                                       
TNBC_Raman_FWHM_third_peak_weight = TNBC_Raman_FWHM_third_peak_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);                                                   
                                                    
TNBC_Raman_FWHM_fourth_peak_weight = TNBC_Raman_FWHM_fourth_peak_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
TNBC_Raman_FWHM_fifth_peak_weight = TNBC_Raman_FWHM_fifth_peak_var*100/sum([10*TNBC_CNP_voltage_var 10*TNBC_CNP_resistance_var TNBC_CNP_FWHM_var TNBC_CNP_slope_var ...
                                                        TNBC_CNP_inter_var 0.5*TNBC_Raman_ratio_DG_band_var TNBC_Raman_ratio_G2D_band_var ...
                                                        TNBC_Raman_shift_D_band_var TNBC_Raman_shift_G_band_var TNBC_Raman_shift_2D_band_var ...
                                                        TNBC_Raman_FWHM_first_peak_var TNBC_Raman_FWHM_second_peak_var TNBC_Raman_FWHM_third_peak_var ...
                                                        TNBC_Raman_FWHM_fourth_peak_var TNBC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
TNBC_weights = [TNBC_CNP_voltage_weight TNBC_CNP_resistance_weight TNBC_CNP_FWHM_weight TNBC_CNP_slope_weight TNBC_CNP_inter_weight ...
                TNBC_Raman_ratio_DG_band_weight TNBC_Raman_ratio_G2D_band_weight TNBC_Raman_shift_D_band_weight TNBC_Raman_shift_G_band_weight ...
                TNBC_Raman_shift_2D_band_weight TNBC_Raman_FWHM_first_peak_weight TNBC_Raman_FWHM_second_peak_weight TNBC_Raman_FWHM_third_peak_weight ...
                TNBC_Raman_FWHM_fourth_peak_weight TNBC_Raman_FWHM_fifth_peak_weight];
            
% ---- CRC ------

CRC_CNP_voltage_mean = [0.44 0.48 0.51 0.485 0.442 0.43 0.425 0.458 0.49 0.505 0.52 0.48 0.45 0.475 0.44];
CRC_CNP_voltage_var = [];
for i=1:length(CRC_CNP_voltage_mean)
    CRC_CNP_voltage_var = [CRC_CNP_voltage_var; abs(CRC_CNP_voltage_mean(i) - 0.45)];
end
CRC_CNP_voltage_var = mean(CRC_CNP_voltage_var)/CNP_voltage_mean*100;

CRC_CNP_resistance_mean = [2450 2470 2480 2465 2439 2500 2480 2452 2460 2453 2463 2471 2466 2469 2451];
CRC_CNP_resistance_var = [];
for i=1:length(CRC_CNP_resistance_mean)
    CRC_CNP_resistance_var = [CRC_CNP_resistance_var; abs(CRC_CNP_resistance_mean(i) - 2440)];
end
CRC_CNP_resistance_var = mean(CRC_CNP_resistance_var)/CNP_resistance_mean*100;

CRC_CNP_FWHM_mean = [0.175 0.182 0.19 0.195 0.205 0.192 0.178 0.185 0.193 0.197 0.204 0.204 0.19 0.183 0.176];
CRC_CNP_FWHM_var = [];
for i=1:length(CRC_CNP_FWHM_mean)
    CRC_CNP_FWHM_var = [CRC_CNP_FWHM_var; abs(CRC_CNP_FWHM_mean(i) - 0.2)];
end
CRC_CNP_FWHM_var = mean(CRC_CNP_FWHM_var)/CNP_FWHM_mean*100;

CRC_CNP_slope_mean = [34 31 40 36 37 39.1 42 41.5 35 38.4 32 41 36 39 41];
CRC_CNP_slope_var = [];
for i=1:length(CRC_CNP_slope_mean)
    CRC_CNP_slope_var = [CRC_CNP_slope_var; abs(CRC_CNP_slope_mean(i) - 38)];
end
CRC_CNP_slope_var = mean(CRC_CNP_slope_var)/CNP_slope_mean*100;

CRC_CNP_inter_mean = [1200 1240 1190 1187 1221 1234 1204 1216 1230 1195 1188 1189 1239 1997 1192];
CRC_CNP_inter_var = [];
for i=1:length(CRC_CNP_inter_mean)
    CRC_CNP_inter_var = [CRC_CNP_inter_var; abs(CRC_CNP_inter_mean(i) - 1215)];
end
CRC_CNP_inter_var = mean(CRC_CNP_inter_var)/CNP_inter_mean*100;

CRC_Raman_ratio_DG_band_mean = [0.86 0.9 0.81 0.79 0.73 0.82 0.84 0.91 0.84 0.86 0.8 0.85 0.78 0.82 0.74];
CRC_Raman_ratio_DG_band_var = [];
for i=1:length(CRC_Raman_ratio_DG_band_mean)
    CRC_Raman_ratio_DG_band_var = [CRC_Raman_ratio_DG_band_var; abs(CRC_Raman_ratio_DG_band_mean(i) - 0.85)];
end
CRC_Raman_ratio_DG_band_var = mean(CRC_Raman_ratio_DG_band_var)/Raman_ratio_DG_band_mean*100;

CRC_Raman_ratio_G2D_band_mean = [0.59 0.55 0.48 0.57 0.61 0.62 0.56 0.49 0.56 0.605 0.56 0.58 0.49 0.48 0.56];
CRC_Raman_ratio_G2D_band_var = [];
for i=1:length(CRC_Raman_ratio_G2D_band_mean)
    CRC_Raman_ratio_G2D_band_var = [CRC_Raman_ratio_G2D_band_var; abs(CRC_Raman_ratio_G2D_band_mean(i) - 0.6)];
end
CRC_Raman_ratio_G2D_band_var = mean(CRC_Raman_ratio_G2D_band_var)/Raman_ratio_G2D_band_mean*100;

CRC_Raman_shift_D_band_mean = [1499 1510 1502 1504 1489 1486 1494 1492 1507 1491 1498 1503 1488 1495 1487];
CRC_Raman_shift_D_band_var = [];
for i=1:length(CRC_Raman_shift_D_band_mean)
    CRC_Raman_shift_D_band_var = [CRC_Raman_shift_D_band_var; abs(CRC_Raman_shift_D_band_mean(i) - 1490)];
end
CRC_Raman_shift_D_band_var = mean(CRC_Raman_shift_D_band_var)/Raman_shift_D_band_mean*100;

CRC_Raman_shift_G_band_mean = [1601 1620 1625 1614 1598 1595 1603 1615 1608 1605 1626 1605 1615 1614 1596];
CRC_Raman_shift_G_band_var = [];
for i=1:length(CRC_Raman_shift_G_band_mean)
    CRC_Raman_shift_G_band_var = [CRC_Raman_shift_G_band_var; abs(CRC_Raman_shift_G_band_mean(i) - 1600)];
end
CRC_Raman_shift_G_band_var = mean(CRC_Raman_shift_G_band_var)/Raman_shift_G_band_mean*100;

CRC_Raman_shift_2D_band_mean = [2701 2705 2709 2716 2721 2680 2688 2693 2697 2698 2702 2722 2687 2694 2720];
CRC_Raman_shift_2D_band_var = [];
for i=1:length(CRC_Raman_shift_2D_band_mean)
    CRC_Raman_shift_2D_band_var = [CRC_Raman_shift_2D_band_var; abs(CRC_Raman_shift_2D_band_mean(i) - 2700)];
end
CRC_Raman_shift_2D_band_var = mean(CRC_Raman_shift_2D_band_var)/Raman_shift_2D_band_mean*100;

CRC_Raman_FWHM_first_peak_mean = [36 30 34 32 35 39 40 31 35.5 37 31 38 39 35 32];
CRC_Raman_FWHM_first_peak_var = [];
for i=1:length(CRC_Raman_FWHM_first_peak_mean)
    CRC_Raman_FWHM_first_peak_var = [CRC_Raman_FWHM_first_peak_var; abs(CRC_Raman_FWHM_first_peak_mean(i) - 35)];
end
CRC_Raman_FWHM_first_peak_var = mean(CRC_Raman_FWHM_first_peak_var)/Raman_FWHM_first_peak_mean*100;

CRC_Raman_FWHM_second_peak_mean = [30 27 25 29.5 32 36 31 30 28 28.5 28 29.1 32 29 35];
CRC_Raman_FWHM_second_peak_var = [];
for i=1:length(CRC_Raman_FWHM_second_peak_mean)
    CRC_Raman_FWHM_second_peak_var = [CRC_Raman_FWHM_second_peak_var; abs(CRC_Raman_FWHM_second_peak_mean(i) - 29)];
end
CRC_Raman_FWHM_second_peak_var = mean(CRC_Raman_FWHM_second_peak_var)/Raman_FWHM_second_peak_mean*100;

CRC_Raman_FWHM_third_peak_mean = [26 32 30 29 22 25 26.5 31 33 22.7 22.8 32 30 27 28];
CRC_Raman_FWHM_third_peak_var = [];
for i=1:length(CRC_Raman_FWHM_third_peak_mean)
    CRC_Raman_FWHM_third_peak_var = [CRC_Raman_FWHM_third_peak_var; abs(CRC_Raman_FWHM_third_peak_mean(i) - 25)];
end
CRC_Raman_FWHM_third_peak_var = mean(CRC_Raman_FWHM_third_peak_var)/Raman_FWHM_third_peak_mean*100;

CRC_Raman_FWHM_fourth_peak_mean = [20 19 17.5 21 24 26 22.5 19.5 21.3 22.8 19.6 22.4 17.6 18 23];
CRC_Raman_FWHM_fourth_peak_var = [];
for i=1:length(CRC_Raman_FWHM_fourth_peak_mean)
    CRC_Raman_FWHM_fourth_peak_var = [CRC_Raman_FWHM_fourth_peak_var; abs(CRC_Raman_FWHM_fourth_peak_mean(i) - 18)];
end
CRC_Raman_FWHM_fourth_peak_var = mean(CRC_Raman_FWHM_fourth_peak_var)/Raman_FWHM_fourth_peak_mean*100;

CRC_Raman_FWHM_fifth_peak_mean = [25 20 23 28 29 31 25.5 26.7 22.2 24.3 24.2 25.7 27 22 27];
CRC_Raman_FWHM_fifth_peak_var = [];
for i=1:length(CRC_Raman_FWHM_fifth_peak_mean)
    CRC_Raman_FWHM_fifth_peak_var = [CRC_Raman_FWHM_fifth_peak_var; abs(CRC_Raman_FWHM_fifth_peak_mean(i) - 24)];
end
CRC_Raman_FWHM_fifth_peak_var = mean(CRC_Raman_FWHM_fifth_peak_var)/Raman_FWHM_fifth_peak_mean*100;

CRC_CNP_voltage_weight = 10*CRC_CNP_voltage_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);
                                                    
CRC_CNP_resistance_weight = 10*CRC_CNP_resistance_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);
                                                    
CRC_CNP_FWHM_weight = CRC_CNP_FWHM_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);

CRC_CNP_slope_weight = CRC_CNP_slope_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);

CRC_CNP_inter_weight = CRC_CNP_inter_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
CRC_Raman_ratio_DG_band_weight = 0.5*CRC_Raman_ratio_DG_band_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
CRC_Raman_ratio_G2D_band_weight = CRC_Raman_ratio_G2D_band_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
CRC_Raman_shift_D_band_weight = CRC_Raman_shift_D_band_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);                                                     
                                                                           
CRC_Raman_shift_G_band_weight = CRC_Raman_shift_G_band_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);  
                                                    
CRC_Raman_shift_2D_band_weight = CRC_Raman_shift_2D_band_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);                                                     
                                                    
CRC_Raman_FWHM_first_peak_weight = CRC_Raman_FWHM_first_peak_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);          
                                                                                                        
CRC_Raman_FWHM_second_peak_weight = CRC_Raman_FWHM_second_peak_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);
                                                                                                       
CRC_Raman_FWHM_third_peak_weight = CRC_Raman_FWHM_third_peak_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);                                                   
                                                    
CRC_Raman_FWHM_fourth_peak_weight = CRC_Raman_FWHM_fourth_peak_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
CRC_Raman_FWHM_fifth_peak_weight = CRC_Raman_FWHM_fifth_peak_var*100/sum([10*CRC_CNP_voltage_var 10*CRC_CNP_resistance_var CRC_CNP_FWHM_var CRC_CNP_slope_var ...
                                                        CRC_CNP_inter_var 0.5*CRC_Raman_ratio_DG_band_var CRC_Raman_ratio_G2D_band_var ...
                                                        CRC_Raman_shift_D_band_var CRC_Raman_shift_G_band_var CRC_Raman_shift_2D_band_var ...
                                                        CRC_Raman_FWHM_first_peak_var CRC_Raman_FWHM_second_peak_var CRC_Raman_FWHM_third_peak_var ...
                                                        CRC_Raman_FWHM_fourth_peak_var CRC_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
CRC_weights = [CRC_CNP_voltage_weight CRC_CNP_resistance_weight CRC_CNP_FWHM_weight CRC_CNP_slope_weight CRC_CNP_inter_weight ...
                CRC_Raman_ratio_DG_band_weight CRC_Raman_ratio_G2D_band_weight CRC_Raman_shift_D_band_weight CRC_Raman_shift_G_band_weight ...
                CRC_Raman_shift_2D_band_weight CRC_Raman_FWHM_first_peak_weight CRC_Raman_FWHM_second_peak_weight CRC_Raman_FWHM_third_peak_weight ...
                CRC_Raman_FWHM_fourth_peak_weight CRC_Raman_FWHM_fifth_peak_weight];
            
% ---- FB ------

FB_CNP_voltage_mean = [0.19 0.18 0.185 0.195 0.2 0.21 0.23 0.21 0.205 0.208 0.185 0.192 0.2 0.188 0.22];
FB_CNP_voltage_var = [];
for i=1:length(FB_CNP_voltage_mean)
    FB_CNP_voltage_var = [FB_CNP_voltage_var; abs(FB_CNP_voltage_mean(i) - 0.2)];
end
FB_CNP_voltage_var = mean(FB_CNP_voltage_var)/CNP_voltage_mean*100;

FB_CNP_resistance_mean = [2355 2400 2403 2380 2360 2365 2349 2345 2370 2347 2356 2364 2346 2362 2357];
FB_CNP_resistance_var = [];
for i=1:length(FB_CNP_resistance_mean)
    FB_CNP_resistance_var = [FB_CNP_resistance_var; abs(FB_CNP_resistance_mean(i) - 2350)];
end
FB_CNP_resistance_var = mean(FB_CNP_resistance_var)/CNP_resistance_mean*100;

FB_CNP_FWHM_mean = [0.215 0.2 0.195 0.202 0.23 0.25 0.217 0.225 0.222 0.205 0.201 0.194 0.23 0.21 0.24];
FB_CNP_FWHM_var = [];
for i=1:length(FB_CNP_FWHM_mean)
    FB_CNP_FWHM_var = [FB_CNP_FWHM_var; abs(FB_CNP_FWHM_mean(i) - 0.21)];
end
FB_CNP_FWHM_var = mean(FB_CNP_FWHM_var)/CNP_FWHM_mean*100;

FB_CNP_slope_mean = [31 26 29 33 34 31.5 30 32 32.5 32.2];
FB_CNP_slope_var = [];
for i=1:length(FB_CNP_slope_mean)
    FB_CNP_slope_var = [FB_CNP_slope_var; abs(FB_CNP_slope_mean(i) - 32)];
end
FB_CNP_slope_var = mean(FB_CNP_slope_var)/CNP_slope_mean*100;

FB_CNP_inter_mean = [1205 1241 1194 1189 1211 1224 1214 1226 1202 1197 1223 1190 1240 1206 1225];
FB_CNP_inter_var = [];
for i=1:length(FB_CNP_inter_mean)
    FB_CNP_inter_var = [FB_CNP_inter_var; abs(FB_CNP_inter_mean(i) - 1225)];
end
FB_CNP_inter_var = mean(FB_CNP_inter_var)/CNP_inter_mean*100;

FB_Raman_ratio_DG_band_mean = [0.37 0.35 0.39 0.41 0.38 0.375 0.356 0.36 0.378 0.365 0.34 0.4 0.38 0.38 0.4];
FB_Raman_ratio_DG_band_var = [];
for i=1:length(FB_Raman_ratio_DG_band_mean)
    FB_Raman_ratio_DG_band_var = [FB_Raman_ratio_DG_band_var; abs(FB_Raman_ratio_DG_band_mean(i) - 0.38)];
end
FB_Raman_ratio_DG_band_var = mean(FB_Raman_ratio_DG_band_var)/Raman_ratio_DG_band_mean*100;

FB_Raman_ratio_G2D_band_mean = [0.59 0.57 0.49 0.605 0.61 0.595 0.587 0.612 0.604 0.602 0.602 0.58 0.605 0.56 0.57];
FB_Raman_ratio_G2D_band_var = [];
for i=1:length(FB_Raman_ratio_G2D_band_mean)
    FB_Raman_ratio_G2D_band_var = [FB_Raman_ratio_G2D_band_var; abs(FB_Raman_ratio_G2D_band_mean(i) - 0.6)];
end
FB_Raman_ratio_G2D_band_var = mean(FB_Raman_ratio_G2D_band_var)/Raman_ratio_G2D_band_mean*100;

FB_Raman_shift_D_band_mean = [1495 1480 1500 1502 1499 1486 1506 1503 1491 1493.5 1501 1483 1498 1487 1479];
FB_Raman_shift_D_band_var = [];
for i=1:length(FB_Raman_shift_D_band_mean)
    FB_Raman_shift_D_band_var = [FB_Raman_shift_D_band_var; abs(FB_Raman_shift_D_band_mean(i) - 1493)];
end
FB_Raman_shift_D_band_var = mean(FB_Raman_shift_D_band_var)/Raman_shift_D_band_mean*100;

FB_Raman_shift_G_band_mean = [1610 1615 1623 1598 1595 1603 1605 1607.8 1611 1612 1605 1614 1606 1622 1613];
FB_Raman_shift_G_band_var = [];
for i=1:length(FB_Raman_shift_G_band_mean)
    FB_Raman_shift_G_band_var = [FB_Raman_shift_G_band_var; abs(FB_Raman_shift_G_band_mean(i) - 1608)];
end
FB_Raman_shift_G_band_var = mean(FB_Raman_shift_G_band_var)/Raman_shift_G_band_mean*100;

FB_Raman_shift_2D_band_mean = [2706 2715 2726 2703 2719 2722 2709 2716 2708 2704 2714 2708 2720 2704 2714];
FB_Raman_shift_2D_band_var = [];
for i=1:length(FB_Raman_shift_2D_band_mean)
    FB_Raman_shift_2D_band_var = [FB_Raman_shift_2D_band_var; abs(FB_Raman_shift_2D_band_mean(i) - 2705)];
end
FB_Raman_shift_2D_band_var = mean(FB_Raman_shift_2D_band_var)/Raman_shift_2D_band_mean*100;

FB_Raman_FWHM_first_peak_mean = [37 33 30 29 40 41 38.5 36.8 39 34];
FB_Raman_FWHM_first_peak_var = [];
for i=1:length(FB_Raman_FWHM_first_peak_mean)
    FB_Raman_FWHM_first_peak_var = [FB_Raman_FWHM_first_peak_var; abs(FB_Raman_FWHM_first_peak_mean(i) - 36)];
end
FB_Raman_FWHM_first_peak_var = mean(FB_Raman_FWHM_first_peak_var)/Raman_FWHM_first_peak_mean*100;

FB_Raman_FWHM_second_peak_mean = [17 19 23 18.5 15.9 20 20.4 16.7 17.2 17.5 18 18.5 17 15.4 16];
FB_Raman_FWHM_second_peak_var = [];
for i=1:length(FB_Raman_FWHM_second_peak_mean)
    FB_Raman_FWHM_second_peak_var = [FB_Raman_FWHM_second_peak_var; abs(FB_Raman_FWHM_second_peak_mean(i) - 16)];
end
FB_Raman_FWHM_second_peak_var = mean(FB_Raman_FWHM_second_peak_var)/Raman_FWHM_second_peak_mean*100;

FB_Raman_FWHM_third_peak_mean = [23 27 31 22 24 24.5 25.7 28 27.4 23.6 23 30 27 23.5 26];
FB_Raman_FWHM_third_peak_var = [];
for i=1:length(FB_Raman_FWHM_third_peak_mean)
    FB_Raman_FWHM_third_peak_var = [FB_Raman_FWHM_third_peak_var; abs(FB_Raman_FWHM_third_peak_mean(i) - 25)];
end
FB_Raman_FWHM_third_peak_var = mean(FB_Raman_FWHM_third_peak_var)/Raman_FWHM_third_peak_mean*100;

FB_Raman_FWHM_fourth_peak_mean = [16 13 17 18 19 21 16.5 17.3 15.9 16.8 22 20 17 15.2 17.4];
FB_Raman_FWHM_fourth_peak_var = [];
for i=1:length(FB_Raman_FWHM_fourth_peak_mean)
    FB_Raman_FWHM_fourth_peak_var = [FB_Raman_FWHM_fourth_peak_var; abs(FB_Raman_FWHM_fourth_peak_mean(i) - 17)];
end
FB_Raman_FWHM_fourth_peak_var = mean(FB_Raman_FWHM_fourth_peak_var)/Raman_FWHM_fourth_peak_mean*100;

FB_Raman_FWHM_fifth_peak_mean = [18 23 17 24 21 20 19.5 18.4 17.9 18.8 23 18 17 16.3 20];
FB_Raman_FWHM_fifth_peak_var = [];
for i=1:length(FB_Raman_FWHM_fifth_peak_mean)
    FB_Raman_FWHM_fifth_peak_var = [FB_Raman_FWHM_fifth_peak_var; abs(FB_Raman_FWHM_fifth_peak_mean(i) - 19)];
end
FB_Raman_FWHM_fifth_peak_var = mean(FB_Raman_FWHM_fifth_peak_var)/Raman_FWHM_fifth_peak_mean*100;

FB_CNP_voltage_weight = 10*FB_CNP_voltage_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);
                                                    
FB_CNP_resistance_weight = 10*FB_CNP_resistance_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);
                                                    
FB_CNP_FWHM_weight = FB_CNP_FWHM_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);

FB_CNP_slope_weight = FB_CNP_slope_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);

FB_CNP_inter_weight = FB_CNP_inter_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
FB_Raman_ratio_DG_band_weight = 0.5*FB_Raman_ratio_DG_band_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
FB_Raman_ratio_G2D_band_weight = FB_Raman_ratio_G2D_band_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
FB_Raman_shift_D_band_weight = FB_Raman_shift_D_band_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);                                                     
                                                                           
FB_Raman_shift_G_band_weight = FB_Raman_shift_G_band_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);  
                                                    
FB_Raman_shift_2D_band_weight = FB_Raman_shift_2D_band_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);                                                     
                                                    
FB_Raman_FWHM_first_peak_weight = FB_Raman_FWHM_first_peak_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);          
                                                                                                        
FB_Raman_FWHM_second_peak_weight = FB_Raman_FWHM_second_peak_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);
                                                                                                       
FB_Raman_FWHM_third_peak_weight = FB_Raman_FWHM_third_peak_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);                                                   
                                                    
FB_Raman_FWHM_fourth_peak_weight = FB_Raman_FWHM_fourth_peak_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
FB_Raman_FWHM_fifth_peak_weight = FB_Raman_FWHM_fifth_peak_var*100/sum([10*FB_CNP_voltage_var 10*FB_CNP_resistance_var FB_CNP_FWHM_var FB_CNP_slope_var ...
                                                        FB_CNP_inter_var 0.5*FB_Raman_ratio_DG_band_var FB_Raman_ratio_G2D_band_var ...
                                                        FB_Raman_shift_D_band_var FB_Raman_shift_G_band_var FB_Raman_shift_2D_band_var ...
                                                        FB_Raman_FWHM_first_peak_var FB_Raman_FWHM_second_peak_var FB_Raman_FWHM_third_peak_var ...
                                                        FB_Raman_FWHM_fourth_peak_var FB_Raman_FWHM_fifth_peak_var]);                                                    
                                                    
FB_weights = [FB_CNP_voltage_weight FB_CNP_resistance_weight FB_CNP_FWHM_weight FB_CNP_slope_weight FB_CNP_inter_weight ...
                FB_Raman_ratio_DG_band_weight FB_Raman_ratio_G2D_band_weight FB_Raman_shift_D_band_weight FB_Raman_shift_G_band_weight ...
                FB_Raman_shift_2D_band_weight FB_Raman_FWHM_first_peak_weight FB_Raman_FWHM_second_peak_weight FB_Raman_FWHM_third_peak_weight ...
                FB_Raman_FWHM_fourth_peak_weight FB_Raman_FWHM_fifth_peak_weight];
            
%% SECTION 3) Generation of the matrix of classification 

M_sens = [];
M_sens = [M_sens; TNBC_weights];
M_sens = [M_sens; CRC_weights];
M_sens = [M_sens; FB_weights];


%% SECTION 4) Data classification example for a data segment of TNBC

input_vector = [0.46 2450 0.205 39 1220 0.86 0.55 1499 1603 2702 34 30 24 19 25]; 

aux = M_sens*(abs(input_vector)./mean_vector_PBS)';
proj_x = aux(1)/sum(aux);
proj_y = aux(2)/sum(aux);
proj_z = aux(3)/sum(aux);

clc
disp('TNBC proj. weight:')
disp(proj_x)
disp('CRC proj. weight:')
disp(proj_y)
disp('FB proj. weight:')
disp(proj_z)

%% SECTION 5) Data classification example for a data segment of CRC

input_vector = [0.6 2640 0.2 44 1515 0.65 0.98 1490 1600 2700 22 28 24 30 28];

aux = M_sens*(abs(input_vector)./mean_vector_PBS)';
proj_x = aux(1)/sum(aux);
proj_y = aux(2)/sum(aux);
proj_z = aux(3)/sum(aux);

clc
disp('TNBC proj. weight:')
disp(proj_x)
disp('CRC proj. weight:')
disp(proj_y)
disp('FB proj. weight:')
disp(proj_z)

%% SECTION 6) Data classification example for a data segment of FB

input_vector = [0.23 2330 0.24 30 1245 0.35 0.61 1497 1608 2725 37 16 25 18 20];

aux = M_sens*(abs(input_vector)./mean_vector_PBS)';
proj_x = aux(1)/sum(aux);
proj_y = aux(2)/sum(aux);
proj_z = aux(3)/sum(aux);

clc
disp('TNBC proj. weight:')
disp(proj_x)
disp('CRC proj. weight:')
disp(proj_y)
disp('FB proj. weight:')
disp(proj_z)
